.django-tabbed-changeform-admin-tabs {
    margin-bottom: 20px;
}

.ui-widget-header {
    background-color: #79aec8;
}

.ui-state-default,
.ui-widget-content .ui-state-default,
.ui-widget-header .ui-state-default,
.ui-button,
html .ui-button.ui-state-disabled:hover,
html .ui-button.ui-state-disabled:active {
    border:1px solid #79aec8;
    background:#79aec8;
    color:#fff
}

.ui-state-default a, .ui-state-default a:link, .ui-state-default a:visited, a.ui-button, a:link.ui-button, a:visited.ui-button, .ui-button {
    color: #fff;
}

.ui-state-active,
.ui-widget-content .ui-state-active,
.ui-widget-header .ui-state-active,
a.ui-button:active,
.ui-button:active,
.ui-button.ui-state-active:hover {
    border:1px solid #fff;
    background:#fff;
}

.ui-state-active a,
.ui-state-active a:link,
.ui-state-active a:visited {
    color: #000;
}

